@@ -342,7 +342,8 @@ class BaseFormSet(object):
             return
         for i in range(0, self.total_form_count()):
             form = self.forms[i]
-            if not form.has_changed():
+            # Empty forms are unchanged forms beyond those with initial data.
+            if not form.has_changed() and i >= self.initial_form_count():
                 empty_forms_count += 1
 
             self._errors.append(form.errors)
